Platform-specific Settings
==========================

.. currentmodule:: sounddevice

.. autosummary::
   :nosignatures:

   AsioSettings
   CoreAudioSettings
   WasapiSettings

.. autoclass:: AsioSettings

.. autoclass:: CoreAudioSettings

.. autoclass:: WasapiSettings
